require "dapi/version"
require 'json'
require_relative "dapi/products/auth"
require_relative "dapi/products/jobs"
require_relative "dapi/products/dataAPI"
require_relative "dapi/products/payment"

include Auth
include Jobs
include DataAPI
include Payment

module Dapi
    class DapiClient
        def initialize(secret)
            @appSecret=secret
        end
    
    
        ###### Authentication API #####
    
    
        def exchangeToken(userSecret, accessCode, connectionID)
            JSON.parse(Auth.exchangeToken(@appSecret, accessCode, connectionID).to_s, object_class: OpenStruct)
        end
    
        def checkLogin(userSecret, token, sync = false, addresses = [])
            JSON.parse(Auth.checkLogin(@appSecret, userSecret, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def delinkUser(userSecret, token)
            JSON.parse(Auth.delinkUser(@appSecret, accessCode).to_s, object_class: OpenStruct)
        end
    
        def refreshAccessToken(userSecret, token)
            JSON.parse(Auth.refreshAccessToken(@appSecret, accessToken).to_s, object_class: OpenStruct)
        end
    
    
        ###### Data API #####
    
    
        def getIdentity(userSecret, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getIdentity(@appSecret, userSecret, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getAccounts(userSecret, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getAccounts(@appSecret, userSecret, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getCards(userSecret, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getCards(@appSecret, userSecret, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getBalance(userSecret, accountID, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getBalance(@appSecret, userSecret, accountID, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getCardBalance(userSecret, cardID, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getCardBalance(@appSecret, userSecret, cardID, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getTranscations(userSecret, accountID, fromDate, toDate, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getTranscations(@appSecret, userSecret, accountID, fromDate, toDate, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getCardTransactions(userSecret, cardID, fromDate, toDate, token, sync = false, addresses = [])
            JSON.parse(DataAPI.getCardTransactions(@appSecret, userSecret, cardID, fromDate, toDate, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def getAccountsMetaData(appSecret, userSecret, sync = false, addresses = [])
            JSON.parse(DataAPI.getAccountsMetaData(@appSecret, userSecret, sync, addresses).to_s, object_class: OpenStruct)
        end
    
    
        ###### Payment API #####
    
    
        def getBeneficiaries(userSecret, token, sync = false, addresses = [])
            JSON.parse(Payment.getBeneficiaries(@appSecret, userSecret, token, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def createBeneficiary(userSecret, token, swiftCode = "", type = "", name = "", accountNumber = "",
            address = "", iban = "",  sync = false, addresses = [])
            JSON.parse(Payment.createBeneficiary(@appSecret, userSecret, token, swiftCode, type, name, accountNumber, address, iban, sync, addresses).to_s, object_class: OpenStruct)
        end
    
        def createTransfer(userSecret, token, receiverID = "", senderID = "", remark = "", sync = false, addresses = [])
            JSON.parse(Payment.createTransfer(@appSecret, userSecret, token, receiverID, senderID, remark, sync, addresses).to_s, object_class: OpenStruct)
        end
    
    
        ###### Jobs API #####
    
    
        def resumeJob(userSecret, token, sync = false, addresses = [])
            JSON.parse(Jobs.resumeJob(appSecret, userSecret, jobID, sync = true, userInputs, addresses).to_s, object_class: OpenStruct)
        end
    
        def jobStatus(userSecret, token, sync = false, addresses = [])
            JSON.parse(Jobs.jobStatus(appSecret, jobID, sync = true, userSecret, addresses).to_s, object_class: OpenStruct)
        end
    
    end
end
